Pyaligner Documentation
=======================


**PyAligner** is a python library to automatically transcribe audio files and align them with the transcription. Check `the GitHub repo <https://github.com/ramajoballester/pyaligner>`_.



Contents
--------

.. toctree::
   :maxdepth: 1

   install
   user_guide
   
